[libgweather/benzea/wip-variant-backend: 37/39] location-entry: Use the dup_world() API in to fetch the top



commit c78b68d13a5f292d9dc3aab66510a94bddf86fd1
Author: Benjamin Berg <bberg redhat com>
Date:   Sun Apr 26 21:36:40 2020 +0200

    location-entry: Use the dup_world() API in to fetch the top

 libgweather/gweather-location-entry.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/libgweather/gweather-location-entry.c b/libgweather/gweather-location-entry.c
index c7862efd..75ee2a71 100644
--- a/libgweather/gweather-location-entry.c
+++ b/libgweather/gweather-location-entry.c
@@ -175,7 +175,7 @@ constructed (GObject *object)
     entry = GWEATHER_LOCATION_ENTRY (object);
 
     if (!entry->priv->top)
-       entry->priv->top = gweather_location_ref (gweather_location_get_world ());
+       entry->priv->top = gweather_location_dup_world ();
 
     store = gtk_tree_store_new (4, G_TYPE_STRING, GWEATHER_TYPE_LOCATION, G_TYPE_STRING, G_TYPE_STRING);
     fill_location_entry_model (store, entry->priv->top, NULL, NULL, NULL, entry->priv->show_named_timezones);
@@ -829,7 +829,7 @@ _no_matches (GtkEntryCompletion *completion, GWeatherLocationEntry *entry) {
  * Creates a new #GWeatherLocationEntry.
  *
  * @top will normally be the location returned from
  * gweather_location_get_world(), but you can create an entry that
  * only accepts a smaller set of locations if you want.
  *
  * Return value: the new #GWeatherLocationEntry
@@ -829,7 +829,7 @@ _no_matches (GtkEntryCompletion *completion, GWeatherLocationEntry *entry) {
  *
  * @top will normally be the location returned from
- * gweather_location_get_world(), but you can create an entry that
+ * gweather_location_dup_world(), but you can create an entry that
  * only accepts a smaller set of locations if you want.
  *


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]